Discounted Cash Flow Models 
============================ 
 
This section includes planned models for discounted cash flow analysis. Contributions are welcome! 
 
- Dividend Discount Model (DDM) 
- Free Cash Flow to Equity (FCFE) 
- Free Cash Flow to Firm (FCFF) 
- Net Present Value (NPV) 
- Internal Rate of Return (IRR) 
- Adjusted Present Value (APV) 
